==> kubernetes-model-4.6.2-sources.jar: annotations/io/fabric8/kubernetes/api/model/HorizontalPodAutoscalerListFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.StringBuffer;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface HorizontalPodAutoscalerListFluent<A extends HorizontalPodAutoscalerListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,HorizontalPodAutoscaler item);
    public A setToItems(int index,HorizontalPodAutoscaler item);
    public A addToItems(HorizontalPodAutoscaler... items);
    public A addAllToItems(Collection<HorizontalPodAutoscaler> items);
    public A removeFromItems(HorizontalPodAutoscaler... items);
    public A removeAllFromItems(Collection<HorizontalPodAutoscaler> items);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<HorizontalPodAutoscaler> getItems();
    public List<HorizontalPodAutoscaler> buildItems();
    public HorizontalPodAutoscaler buildItem(int index);
    public HorizontalPodAutoscaler buildFirstItem();
    public HorizontalPodAutoscaler buildLastItem();
    public HorizontalPodAutoscaler buildMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<HorizontalPodAutoscalerBuilder> predicate);
    public Boolean hasMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<HorizontalPodAutoscalerBuilder> predicate);
    public A withItems(List<HorizontalPodAutoscaler> items);
    public A withItems(HorizontalPodAutoscaler... items);
    public Boolean hasItems();
    public HorizontalPodAutoscalerListFluent.ItemsNested<A> addNewItem();
    public HorizontalPodAutoscalerListFluent.ItemsNested<A> addNewItemLike(HorizontalPodAutoscaler item);
    public HorizontalPodAutoscalerListFluent.ItemsNested<A> setNewItemLike(int index,HorizontalPodAutoscaler item);
    public HorizontalPodAutoscalerListFluent.ItemsNested<A> editItem(int index);
    public HorizontalPodAutoscalerListFluent.ItemsNested<A> editFirstItem();
    public HorizontalPodAutoscalerListFluent.ItemsNested<A> editLastItem();
    public HorizontalPodAutoscalerListFluent.ItemsNested<A> editMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<HorizontalPodAutoscalerBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ListMeta getMetadata();
    public ListMeta buildMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public HorizontalPodAutoscalerListFluent.MetadataNested<A> withNewMetadata();
    public HorizontalPodAutoscalerListFluent.MetadataNested<A> withNewMetadataLike(ListMeta item);
    public HorizontalPodAutoscalerListFluent.MetadataNested<A> editMetadata();
    public HorizontalPodAutoscalerListFluent.MetadataNested<A> editOrNewMetadata();
    public HorizontalPodAutoscalerListFluent.MetadataNested<A> editOrNewMetadataLike(ListMeta item);

    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,HorizontalPodAutoscalerFluent<HorizontalPodAutoscalerListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}
    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ListMetaFluent<HorizontalPodAutoscalerListFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}

==> kubernetes-model-4.9.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/HorizontalPodAutoscalerListFluent.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.StringBuffer;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface HorizontalPodAutoscalerListFluent<A extends HorizontalPodAutoscalerListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,HorizontalPodAutoscaler item);
    public A setToItems(int index,HorizontalPodAutoscaler item);
    public A addToItems(HorizontalPodAutoscaler... items);
    public A addAllToItems(Collection<HorizontalPodAutoscaler> items);
    public A removeFromItems(HorizontalPodAutoscaler... items);
    public A removeAllFromItems(Collection<HorizontalPodAutoscaler> items);
    public A removeMatchingFromItems(io.fabric8.kubernetes.api.builder.Predicate<HorizontalPodAutoscalerBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<HorizontalPodAutoscaler> getItems();
    public List<HorizontalPodAutoscaler> buildItems();
    public HorizontalPodAutoscaler buildItem(int index);
    public HorizontalPodAutoscaler buildFirstItem();
    public HorizontalPodAutoscaler buildLastItem();
    public HorizontalPodAutoscaler buildMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<HorizontalPodAutoscalerBuilder> predicate);
    public Boolean hasMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<HorizontalPodAutoscalerBuilder> predicate);
    public A withItems(List<HorizontalPodAutoscaler> items);
    public A withItems(HorizontalPodAutoscaler... items);
    public Boolean hasItems();
    public HorizontalPodAutoscalerListFluent.ItemsNested<A> addNewItem();
    public HorizontalPodAutoscalerListFluent.ItemsNested<A> addNewItemLike(HorizontalPodAutoscaler item);
    public HorizontalPodAutoscalerListFluent.ItemsNested<A> setNewItemLike(int index,HorizontalPodAutoscaler item);
    public HorizontalPodAutoscalerListFluent.ItemsNested<A> editItem(int index);
    public HorizontalPodAutoscalerListFluent.ItemsNested<A> editFirstItem();
    public HorizontalPodAutoscalerListFluent.ItemsNested<A> editLastItem();
    public HorizontalPodAutoscalerListFluent.ItemsNested<A> editMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<HorizontalPodAutoscalerBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ListMeta getMetadata();
    public ListMeta buildMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public HorizontalPodAutoscalerListFluent.MetadataNested<A> withNewMetadata();
    public HorizontalPodAutoscalerListFluent.MetadataNested<A> withNewMetadataLike(ListMeta item);
    public HorizontalPodAutoscalerListFluent.MetadataNested<A> editMetadata();
    public HorizontalPodAutoscalerListFluent.MetadataNested<A> editOrNewMetadata();
    public HorizontalPodAutoscalerListFluent.MetadataNested<A> editOrNewMetadataLike(ListMeta item);

    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,HorizontalPodAutoscalerFluent<HorizontalPodAutoscalerListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}
    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ListMetaFluent<HorizontalPodAutoscalerListFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}
